Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var SEQ []byte
Functions ¶
Types ¶
type Index ¶
type Index struct {
SA []uint32 // suffix array
OCC map[byte][]uint32 // occurence table
C map[byte]uint32 // count table
EP map[byte]uint32 // ending row/position of each symbol
LEN uint32
END_POS uint32 // position of "$" in the text
SYMBOLS []int // sorted symbols
Freq map[byte]uint32 // Frequency of each symbol
}
type WorkSpace ¶
type WorkSpace struct {
// contains filtered or unexported fields
}
WorkSpace contains the O(1) scratch space used in constructing a suffix array with an alphabet of sisze 256 (any byte value).
func (*WorkSpace) ComputeSuffixArray ¶
Compute the suffix array of S, storing it into SA. len(S) and len(SA) must be equal.
Click to show internal directories.
Click to hide internal directories.